package cli

import (
	"fofax/internal/table"
)

type usage struct {
	Query       string `table:"Query"`
	Explanation string `table:"Explanation"`
}

func ShowUsage() {
	data := []usage{
		{`title="beijing"`, `从标题中搜索"北京"`},
		{``, ``},
		{`header="elastic"`, `从http头中搜索"elastic"`},
		{``, ``},
		{`body="网络空间测绘"`, `从html正文中搜索"网络空间测绘"`},
		{``, ``},
		{`title="beijing"`, `从标题中搜索"北京"`},
		{``, ``},
		{`header="elastic"`, `从http头中搜索"elastic"`},
		{``, ``},
		{`body="网络空间测绘"`, `从html正文中搜索"网络空间测绘"`},
		{``, ``},
		{`fid="kIlUsGZ8pT6AtgKSKD63iw=="`, `查找相同的网站指纹`},
		{``, ``},
		{`domain="google.com"`, `搜索根域名带有google.com的网站`},
		{``, ``},
		{`icp="京ICP证030173号"`, `查找备案号为"京ICP证030173号"的网站`},
		{``, ``},
		{`js_name="js/jquery.js"`, `查找网站正文中包含js/jquery.js的资产`},
		{``, ``},
		{`js_md5="82ac3f14327a8b7ba49baa208d4eaa15"`, `查找js源码与之匹配的资产`},
		{``, ``},
		{`cname="inst.siteforce.com"`, `查找cname为"inst.xx.com"的网站`},
		{``, ``},
		{`cname_domain="xx.com"`, `查找cname包含"xx.com"的网站`},
		{``, ``},
		{`icon_hash="-247388890"`, `搜索使用此icon的资产,高级会员使用`},
		{``, ``},
		{`host=".google.com"`, `从url中搜索".google.com"`},
		{``, ``},
		{`port="6379"`, `搜索对应"6379"端口的资产`},
		{``, ``},
		{`ip="1.1.1.1"`, `搜索从ip中包含"1.1.1.1"的网站`},
		{``, ``},
		{`ip="1.1.1.1/24"`, `查询IP为"1.1.1.1"的C网段资产`},
		{``, ``},
		{`status_code="402"`, `查询服务器状态为"402"的资产`},
		{``, ``},
		{`protocol="quic"`, `查询 quic 协议资产`},
		{``, ``},
		{`country="CN"`, `搜索指定国家(编码)的资产`},
		{``, ``},
		{`region="Xinjiang"`, `搜索指定行政区的资产`},
		{``, ``},
		{`city="Ürümqi"`, `搜索指定城市的资产`},
		{``, ``},
		{`cert="google"`, `搜索证书(https或者imaps等)`},
		{``, `中带有 google 的资产`},
		{``, ``},
		{`cert.subject="Oracle Corporation"`, `搜索证书持有者是Oracle `},
		{``, `Corporation的资产`},
		{``, ``},
		{`cert.issuer="DigiCert"`, `搜索证书颁发者为DigiCert Inc的资产`},
		{``, ``},
		{`cert.is_valid=true`, `验证证书是否有效,true有效`},
		{``, `,false无效,高级会员使用`},
		{``, ``},
		{`banner=users && protocol=ftp`, `搜索FTP协议中带有users文本的资产`},
		{``, ``},
		{`type=service`, `支持subdomain和service两种`},
		{``, ``},
		{`os="centos"`, `搜索CentOS资产`},
		{``, ``},
		{`server=="Microsoft-IIS/10"`, `搜索IIS 10服务器`},
		{``, ``},
		{`app="Microsoft-Exchange"`, `搜索Microsoft-Exchange设备`},
		{``, ``},
		{`after="2017" && before="2017-10-01"`, `时间范围段`},
		{``, ``},
		{`asn="19551"`, `指定asn的资产`},
		{``, ``},
		{`org="LLC Baxet"`, `指定org(组织)的资产`},
		{``, ``},
		{`base_protocol="udp"`, `指定udp协议的资产`},
		{``, ``},
		{`is_fraud=false`, `排除仿冒/欺诈数据`},
		{``, ``},
		{`is_honeypot=false`, `排除蜜罐数据,高级会员使用`},
		{``, ``},
		{`is_ipv6=true`, `ipv6的资产,true or false`},
		{``, ``},
		{`is_domain=true`, `域名的资产,true or false`},
		{``, ``},
		{`port_size="6"`, `开放端口等于"6"的资产,会员使用`},
		{``, ``},
		{`port_size_gt="6"`, `开放端口大于"6"的资产,会员使用`},
		{``, ``},
		{`port_size_lt="6"`, `开放端口小于"6"的资产,会员使用`},
		{``, ``},
		{`ip_ports="80,161"`, `搜索同时开放80和161端口的ip`},
		{``, ``},
		{`ip_country="CN"`, `搜索中国的ip资产`},
		{``, ``},
		{`ip_region="Zhejiang"`, `搜索指定行政区的ip资产`},
		{``, ``},
		{`ip_city="Hangzhou"`, `搜索指定城市的ip资产`},
		{``, ``},
		{`ip_after="2021-03-18"`, `搜索2021-03-18以后的ip资产`},
		{``, ``},
		{`ip_before="2019-09-09"`, `搜索2019-09-09以前的ip资产`},
	}
	table.Output(data)
}
